@@ -11,6 +11,7 @@ from esphome.const import (
     CONF_POWER,
     CONF_ENERGY,
     CONF_SEL_PIN,
+    CONF_MODEL,
     CONF_VOLTAGE,
     CONF_VOLTAGE_DIVIDER,
     DEVICE_CLASS_CURRENT,
@@ -18,6 +19,8 @@ from esphome.const import (
     DEVICE_CLASS_POWER,
     DEVICE_CLASS_VOLTAGE,
     ICON_EMPTY,
+    LAST_RESET_TYPE_AUTO,
+    STATE_CLASS_MEASUREMENT,
     UNIT_VOLT,
     UNIT_AMPERE,
     UNIT_WATT,
@@ -29,11 +32,19 @@ AUTO_LOAD = ["pulse_counter"]
 hlw8012_ns = cg.esphome_ns.namespace("hlw8012")
 HLW8012Component = hlw8012_ns.class_("HLW8012Component", cg.PollingComponent)
 HLW8012InitialMode = hlw8012_ns.enum("HLW8012InitialMode")
+HLW8012SensorModels = hlw8012_ns.enum("HLW8012SensorModels")
+
 INITIAL_MODES = {
     CONF_CURRENT: HLW8012InitialMode.HLW8012_INITIAL_MODE_CURRENT,
     CONF_VOLTAGE: HLW8012InitialMode.HLW8012_INITIAL_MODE_VOLTAGE,
 }
 
+MODELS = {
+    "HLW8012": HLW8012SensorModels.HLW8012_SENSOR_MODEL_HLW8012,
+    "CSE7759": HLW8012SensorModels.HLW8012_SENSOR_MODEL_CSE7759,
+    "BL0937": HLW8012SensorModels.HLW8012_SENSOR_MODEL_BL0937,
+}
+
 CONF_CF1_PIN = "cf1_pin"
 CONF_CF_PIN = "cf_pin"
 CONFIG_SCHEMA = cv.Schema(
@@ -47,19 +58,25 @@ CONFIG_SCHEMA = cv.Schema(
             pins.internal_gpio_input_pullup_pin_schema, pins.validate_has_interrupt
         ),
         cv.Optional(CONF_VOLTAGE): sensor.sensor_schema(
-            UNIT_VOLT, ICON_EMPTY, 1, DEVICE_CLASS_VOLTAGE
+            UNIT_VOLT, ICON_EMPTY, 1, DEVICE_CLASS_VOLTAGE, STATE_CLASS_MEASUREMENT
         ),
         cv.Optional(CONF_CURRENT): sensor.sensor_schema(
-            UNIT_AMPERE, ICON_EMPTY, 2, DEVICE_CLASS_CURRENT
+            UNIT_AMPERE, ICON_EMPTY, 2, DEVICE_CLASS_CURRENT, STATE_CLASS_MEASUREMENT
         ),
         cv.Optional(CONF_POWER): sensor.sensor_schema(
-            UNIT_WATT, ICON_EMPTY, 1, DEVICE_CLASS_POWER
+            UNIT_WATT, ICON_EMPTY, 1, DEVICE_CLASS_POWER, STATE_CLASS_MEASUREMENT
         ),
         cv.Optional(CONF_ENERGY): sensor.sensor_schema(
-            UNIT_WATT_HOURS, ICON_EMPTY, 1, DEVICE_CLASS_ENERGY
+            UNIT_WATT_HOURS,
+            ICON_EMPTY,
+            1,
+            DEVICE_CLASS_ENERGY,
+            STATE_CLASS_MEASUREMENT,
+            LAST_RESET_TYPE_AUTO,
         ),
         cv.Optional(CONF_CURRENT_RESISTOR, default=0.001): cv.resistance,
         cv.Optional(CONF_VOLTAGE_DIVIDER, default=2351): cv.positive_float,
+        cv.Optional(CONF_MODEL, default="HLW8012"): cv.enum(MODELS, upper=True),
         cv.Optional(CONF_CHANGE_MODE_EVERY, default=8): cv.All(
             cv.uint32_t, cv.Range(min=1)
         ),
@@ -70,30 +87,31 @@ CONFIG_SCHEMA = cv.Schema(
 ).extend(cv.polling_component_schema("60s"))
 
 
-def to_code(config):
+async def to_code(config):
     var = cg.new_Pvariable(config[CONF_ID])
-    yield cg.register_component(var, config)
+    await cg.register_component(var, config)
 
-    sel = yield cg.gpio_pin_expression(config[CONF_SEL_PIN])
+    sel = await cg.gpio_pin_expression(config[CONF_SEL_PIN])
     cg.add(var.set_sel_pin(sel))
-    cf = yield cg.gpio_pin_expression(config[CONF_CF_PIN])
+    cf = await cg.gpio_pin_expression(config[CONF_CF_PIN])
     cg.add(var.set_cf_pin(cf))
-    cf1 = yield cg.gpio_pin_expression(config[CONF_CF1_PIN])
+    cf1 = await cg.gpio_pin_expression(config[CONF_CF1_PIN])
     cg.add(var.set_cf1_pin(cf1))
 
     if CONF_VOLTAGE in config:
-        sens = yield sensor.new_sensor(config[CONF_VOLTAGE])
+        sens = await sensor.new_sensor(config[CONF_VOLTAGE])
         cg.add(var.set_voltage_sensor(sens))
     if CONF_CURRENT in config:
-        sens = yield sensor.new_sensor(config[CONF_CURRENT])
+        sens = await sensor.new_sensor(config[CONF_CURRENT])
         cg.add(var.set_current_sensor(sens))
     if CONF_POWER in config:
-        sens = yield sensor.new_sensor(config[CONF_POWER])
+        sens = await sensor.new_sensor(config[CONF_POWER])
         cg.add(var.set_power_sensor(sens))
     if CONF_ENERGY in config:
-        sens = yield sensor.new_sensor(config[CONF_ENERGY])
+        sens = await sensor.new_sensor(config[CONF_ENERGY])
         cg.add(var.set_energy_sensor(sens))
     cg.add(var.set_current_resistor(config[CONF_CURRENT_RESISTOR]))
     cg.add(var.set_voltage_divider(config[CONF_VOLTAGE_DIVIDER]))
     cg.add(var.set_change_mode_every(config[CONF_CHANGE_MODE_EVERY]))
     cg.add(var.set_initial_mode(INITIAL_MODES[config[CONF_INITIAL_MODE]]))
+    cg.add(var.set_sensor_model(config[CONF_MODEL]))
