@@ -1,5 +1,7 @@
 #pragma once
 
+#include <utility>
+
 #include "light_effect.h"
 #include "esphome/core/automation.h"
 
@@ -11,6 +13,40 @@ inline static float random_cubic_float() {
   return r * r * r;
 }
 
+/// Pulse effect.
+class PulseLightEffect : public LightEffect {
+ public:
+  explicit PulseLightEffect(const std::string &name) : LightEffect(name) {}
+
+  void apply() override {
+    const uint32_t now = millis();
+    if (now - this->last_color_change_ < this->update_interval_) {
+      return;
+    }
+    auto call = this->state_->turn_on();
+    float out = this->on_ ? 1.0 : 0.0;
+    call.set_brightness_if_supported(out);
+    this->on_ = !this->on_;
+    call.set_transition_length_if_supported(this->transition_length_);
+    // don't tell HA every change
+    call.set_publish(false);
+    call.set_save(false);
+    call.perform();
+
+    this->last_color_change_ = now;
+  }
+
+  void set_transition_length(uint32_t transition_length) { this->transition_length_ = transition_length; }
+
+  void set_update_interval(uint32_t update_interval) { this->update_interval_ = update_interval; }
+
+ protected:
+  bool on_ = false;
+  uint32_t last_color_change_{0};
+  uint32_t transition_length_{};
+  uint32_t update_interval_{};
+};
+
 /// Random effect. Sets random colors every 10 seconds and slowly transitions between them.
 class RandomLightEffect : public LightEffect {
  public:
@@ -22,10 +58,14 @@ class RandomLightEffect : public LightEffect {
       return;
     }
     auto call = this->state_->turn_on();
-    call.set_red_if_supported(random_float());
-    call.set_green_if_supported(random_float());
-    call.set_blue_if_supported(random_float());
-    call.set_white_if_supported(random_float());
+    if (this->state_->get_traits().get_supports_rgb()) {
+      call.set_red_if_supported(random_float());
+      call.set_green_if_supported(random_float());
+      call.set_blue_if_supported(random_float());
+      call.set_white_if_supported(random_float());
+    } else {
+      call.set_brightness_if_supported(random_float());
+    }
     call.set_color_temperature_if_supported(random_float());
     call.set_transition_length_if_supported(this->transition_length_);
     call.set_publish(true);
@@ -47,8 +87,8 @@ class RandomLightEffect : public LightEffect {
 
 class LambdaLightEffect : public LightEffect {
  public:
-  LambdaLightEffect(const std::string &name, const std::function<void()> &f, uint32_t update_interval)
-      : LightEffect(name), f_(f), update_interval_(update_interval) {}
+  LambdaLightEffect(const std::string &name, std::function<void()> f, uint32_t update_interval)
+      : LightEffect(name), f_(std::move(f)), update_interval_(update_interval) {}
 
   void apply() override {
     const uint32_t now = millis();
@@ -67,9 +107,9 @@ class LambdaLightEffect : public LightEffect {
 class AutomationLightEffect : public LightEffect {
  public:
   AutomationLightEffect(const std::string &name) : LightEffect(name) {}
-  void stop() override { this->trig_->stop(); }
+  void stop() override { this->trig_->stop_action(); }
   void apply() override {
-    if (!this->trig_->is_running()) {
+    if (!this->trig_->is_action_running()) {
       this->trig_->trigger();
     }
   }
