@@ -1018,9 +1018,11 @@ def requires_component(comp):
 uint8_t = int_range(min=0, max=255)
 uint16_t = int_range(min=0, max=65535)
 uint32_t = int_range(min=0, max=4294967295)
+uint64_t = int_range(min=0, max=18446744073709551615)
 hex_uint8_t = hex_int_range(min=0, max=255)
 hex_uint16_t = hex_int_range(min=0, max=65535)
 hex_uint32_t = hex_int_range(min=0, max=4294967295)
+hex_uint64_t = hex_int_range(min=0, max=18446744073709551615)
 i2c_address = hex_uint8_t
 
 
